@@ -21,7 +21,7 @@ you can configure custom drive_id and folder_id from dashboard to save file in t
 Note: Some appdrive links don't need authorization ( email, password) like :( ex:  https://appdrive.info/file/m6p1PbFF49aqb4MOHrz1 ) , whereas some need authorization ( ex: https://appdrive.info/file/78owWyzsKPRuU5QB2VyG)
 
 Regex: 
-https?://(appdrive|driveapp|drivehub|gdflix|drivesharer|drivebit|drivelinks|driveace|drivepro)\.(info|in|pro|top)\/file/\S+
+https?://(anidrive|driveroot|driveflix|indidrive|drivehub|appdrive|driveapp|driveace|gdflix|drivelinks|drivebit|drivesharer|drivepro)\.\S+
 
 Domains Examples:
 https://appdrive.info/file/78owWyzsKPRuU5QB2VyG
@@ -29,8 +29,7 @@ https://gdflix.top/file/8orswDGb6i
 https://gdflix.pro/file/24pEEKH1Vp
 
 
-appdrive_bypass("https://appdrive.info/file/m6p1PbFF49aqb4MOHrz1", email="xyz@gmail.com", password="appdrive", drive_id="your_td_drive_id", folder_id="folder_id_of_that_td")
-
+appdrive_bypass("https://appdrive.info/file/m6p1PbFF49aqb4MOHrz1", appdrive_email="xyz@gmail.com", appdrive_password="appdrive")
 
 """
 
@@ -57,12 +56,12 @@ def gen_payload(data, boundary=f'{"-"*6}_'):
 
 
 def appdrive_lookalike(client, drive_link):
-	try:
-		response = client.get(drive_link).text
-		soup = BeautifulSoup(response, "html.parser")
-		new_drive_link = soup.find(class_="btn").get("href")
-		return new_drive_link
-	except: return drive_link
+    try:
+        response = client.get(drive_link).text
+        soup = BeautifulSoup(response, "html.parser")
+        new_drive_link = soup.find(class_="btn").get("href")
+        return new_drive_link
+    except: return drive_link
 
 			
 def appdrive_bypass(url: str, appdrive_email=None, appdrive_password=None) -> str:
@@ -75,11 +74,11 @@ def appdrive_bypass(url: str, appdrive_email=None, appdrive_password=None) -> st
     url = client.get(url).url 
     response = client.get(url)   
     try:
-    	key = re.findall('"key",\s+"(.*?)"', response.text)[0]
-    	soup = BeautifulSoup(response.text,  "html.parser")
-    	ddl_btn = soup.find(id="drc")	    	    	
+        key = re.findall('"key",\s+"(.*?)"', response.text)[0]
+        soup = BeautifulSoup(response.text,  "html.parser")
+        ddl_btn = soup.find(id="drc")
     except:
-    	return "Something went wrong. Could not generate GDrive URL for your Given Link"
+        return "Something went wrong. Could not generate GDrive URL for your Given Link"
     
     headers = { "Content-Type": f"multipart/form-data; boundary={'-'*4}_"} 
     data = { 'type': 1,  'key': key, 'action': 'original'}
@@ -95,9 +94,9 @@ def appdrive_bypass(url: str, appdrive_email=None, appdrive_password=None) -> st
  
         
     if 'url' in response:
-    	drive_link = response["url"]
-    	if urlparse(url).netloc in ("driveapp.in", "drivehub.in" , "gdflix.pro", "drivesharer.in", "drivebit.in", "drivelinks.in", "driveace.in", "drivepro.in", "gdflix.top"): return appdrive_lookalike(client,  drive_link)
-    	else : return drive_link 
+        drive_link = response["url"]
+        if urlparse(url).netloc in ("driveapp.in", "drivehub.in" , "gdflix.pro", "drivesharer.in", "drivebit.in", "drivelinks.in", "driveace.in", "drivepro.in", "gdflix.top"): return appdrive_lookalike(client,  drive_link)
+        else : return drive_link
     		     	 	
     elif  'error' in response and response['error']: return response['message']
     else: return "Something went wrong. Could not generate GDrive URL for your Given Link"
@@ -105,4 +104,3 @@ def appdrive_bypass(url: str, appdrive_email=None, appdrive_password=None) -> st
 
 
 
-
