@@ -1,8 +1,7 @@
 __title__ = "PyBypass"
 __description__ = "Python module for bypassing different kind of links."
-__version__ = "2.0.0"
-__author__ = "sanjit sinha"
+__version__ = "2.0.1"
+__author__ = "Sanjit Sinha"
 __author_email__ = "sanjitsinha@anipirates.eu.org"
 __license__ = "MIT"
-__copyright__ = "copyright 2022 sanjit sinha"
-
+__copyright__ = "Copyright 2022 @ Sanjit Sinha"
